﻿//============================================================================
//DSS REST API Learning Tutorial 11: main program code
//Goal:  search for equity instruments, and display their details.
//       In this example we search for active instruments, using as criteria:
//       - their status (active)
//       - a list of exchange codes
//       - a ticker.
//       This code could be modified to use other criteria.
//============================================================================
//To facilitate the learning process, the member declarations are at the start,
//followed by the main and finally the methods.
//============================================================================
using System;
using System.Linq;
using DataScope.Select.Api.Content;
using DataScope.Select.Core.RestApi;
using DataScope.Select.Api.Search;
using DataScope.Select.Api.Content.Equity;
using System.Collections.Generic;
using DssRestfulApiTutorials;

namespace DssRestfulApiTutorials
{
    class Program
    {
        //=====================================================================
        //Member declarations
        //=====================================================================
        private static string dssUserName = "YourUserId";
        private static string dssUserPassword = "YourPassword";

        //=====================================================================
        //Main program entry
        //=====================================================================
        static void Main()
        {
            //-----------------------------------------------------------------
            //Connect and authenticate to the DSS server:
            //-----------------------------------------------------------------
            DssClient dssClient = new DssClient();

            dssClient.ConnectToServer(dssUserName, dssUserPassword);
            DebugPrintAndWaitForEnter("Returned session token: " + dssClient.SessionToken);

            //Expose the searchContext from dssClient:
            SearchContext searchContext = dssClient.searchContext;

            //-----------------------------------------------------------------
            //Perform the equity search.
            //The search criteria can be modified to suit your needs:
            //-----------------------------------------------------------------
            searchContext.Preferences.MaxPageSize = 100;
            IDssEnumerable<EquitySearchResult> resultingInstruments =
                searchContext.EquitySearch(
                    EquitySearchRequest.Create(
                        null,                    //Sub types
                        null,                    //Asset categories
                        null,                    //Company name
                        null,                    //Currency codes
                        null,                    //Description
                        null,                    //Domiciles codes
                        null,                    //Fair value indicator
                        new [] { "PAR", "SWX" }, //Exchange codes
                        null,                    //GICs codes
                        null,                    //File codes
                        null,                    //Org identifier
                        EquityStatus.Active,     //Asset status
                        "IBM",                    //Ticker
		                IdentifierType.Ric,      //Identifier type
                        null,                    //Identifier
                        IdentifierType.Ric));    //Preferred identifier type

            //-----------------------------------------------------------------
            //Data treatment starts here. We just display it on screen:
            //-----------------------------------------------------------------
            DisplayInstrumentDetails(resultingInstruments);

            DebugPrintAndWaitForEnter("\nSearch completed.");
        }

        //=====================================================================
        //Helper methods
        //=====================================================================
        static void DebugPrintAndWaitForEnter(string messageToPrint)
        {
            Console.WriteLine(messageToPrint);
            Console.WriteLine("Press Enter to continue");
            Console.ReadLine();
        }

        static void DisplayInstrumentDetails(IDssEnumerable<EquitySearchResult> resultingInstruments)
        {
            Console.WriteLine("Search results:");
            foreach (EquitySearchResult instrument in resultingInstruments)
            {
                Console.WriteLine("{0}\n - IdentifierType: {1}\n - InstrumentType: {2}\n - Source: {3}\n - Status: {4}\n - Description: {5}",
                    instrument.Identifier,
                    instrument.IdentifierType, instrument.InstrumentType,
                    instrument.Source, instrument.Status, instrument.Description);
            }
            int numberOfResults = resultingInstruments.Count();
            Console.WriteLine("\nNumber of results: {0}", numberOfResults);
        }
    }
}
